# Exhaustive Search with Bayesian Model Averaging (ExhBMA)

# Installation
```
pip install exhbma
```

# Documentation
User documentation is available [here](https://exhbma.readthedocs.io/en/latest/index.html).
You can also try sample notebooks in `tutorials` directory.

# Reference paper
In preparing.
